@@ -1,9 +1,10 @@
 #!/bin/sh
 set -e
 
-readonly SWIFTTAG=5.6.3
-readonly YAMS_VERSION=4.0.2
-readonly SAP_VERSION=1.0.3
+readonly SWIFTTAG=5.7.3
+readonly YAMS_VERSION=5.0.1
+readonly SAP_VERSION=0.4.3
+readonly SWIFT_ARGUMENT_PARSER_VERSION=1.0.3
 readonly SWIFT_CRYPTO_VERSION=1.1.5
 readonly SWIFT_ATOMICS_VERSION=1.0.2
 readonly SWIFT_COLLECTIONS_VERSION=1.0.1
@@ -11,7 +12,7 @@ readonly SWIFT_NUMERICS_VERSION=1.0.1
 readonly SWIFT_SYSTEM_VERSION=1.1.1
 readonly SWIFT_NIO_VERSION=2.31.2
 readonly SWIFT_NIO_SSL_VERSION=2.15.0
-readonly SWIFT_CMARK_GFM=5.6-gfm
+readonly SWIFT_CMARK_GFM=5.7-gfm
 
 mkdir -p swift-repack
 cd swift-repack
@@ -166,8 +167,8 @@ if [ -f "../swiftlang_$SWIFTTAG.orig-swift-argument-parser.tar.gz" ];
 then
     echo "Found existing swiftlang_$SWIFTTAG.orig-swift-argument-parser.tar.gz"
 else
-    wget https://github.com/apple/swift-argument-parser/archive/$SAP_VERSION.tar.gz
-    mv -f $SAP_VERSION.tar.gz ../swiftlang_$SWIFTTAG.orig-swift-argument-parser.tar.gz
+    wget https://github.com/apple/swift-argument-parser/archive/refs/tags/$SWIFT_ARGUMENT_PARSER_VERSION.tar.gz
+    mv -f $SWIFT_ARGUMENT_PARSER_VERSION.tar.gz ../swiftlang_$SWIFTTAG.orig-swift-argument-parser.tar.gz
 fi
 mkdir swift-argument-parser
 tar -C swift-argument-parser -xzf ../swiftlang_$SWIFTTAG.orig-swift-argument-parser.tar.gz --strip-components=1
@@ -347,6 +348,16 @@ fi
 unzip -q ../swiftlang_$SWIFTTAG.orig-swift-nio-ssl.zip
 mv swift-nio-ssl-$SWIFT_NIO_SSL_VERSION swift-nio-ssl
 
+if [ -f "../swiftlang_$SWIFTTAG.orig-swift-format.tar.gz" ];
+then
+    echo "Found existing swiftlang_$SWIFTTAG.orig-swift-format.tar.gz"
+else
+    wget https://github.com/apple/swift-format/archive/swift-$SWIFTTAG-RELEASE.tar.gz
+    mv -f swift-$SWIFTTAG-RELEASE.tar.gz ../swiftlang_$SWIFTTAG.orig-swift-format.tar.gz
+fi
+mkdir swift-format
+tar -C swift-format -xzf ../swiftlang_$SWIFTTAG.orig-swift-format.tar.gz --strip-components=1
+
 
 if [ -f "../swiftlang_$SWIFTTAG.orig-swift-cmark-gfm.zip" ];
 then
